==============================
 Flask <-> Celery Integration
==============================
:Version: 2.2.5

Requires `Celery`_ 2.2.0 or later.

.. _Celery: http://celeryproject.org


See ``example.py`` for example usage.
